#ifndef NT2_INCLUDE_CONSTANTS_MAXEXPONENT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MAXEXPONENT_HPP_INCLUDED

#include <nt2/constant/include/constants/maxexponent.hpp>

#endif
